package betterquesting.api2.client.gui.resources.textures;

import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.resources.colors.IGuiColor;
import javax.annotation.Nullable;
import net.minecraft.util.ResourceLocation;

/* loaded from: betterquesting_api2_client_gui_resources_textures.jar:betterquesting/api2/client/gui/resources/textures/SlideShowTexture.class */
public class SlideShowTexture implements IGuiTexture {
    private final IGuiTexture[] slides;
    private final float interval;

    public SlideShowTexture(float interval, IGuiTexture... slides) {
        this.slides = slides;
        this.interval = interval;
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public void drawTexture(int x, int y, int width, int height, float zLevel, float partialTick) {
        IGuiTexture tex;
        if (width <= 0 || height <= 0 || this.slides.length <= 0 || (tex = getCurrentFrame()) == null) {
            return;
        }
        tex.drawTexture(x, y, width, height, zLevel, partialTick);
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    public void drawTexture(int x, int y, int width, int height, float zDepth, float partialTick, IGuiColor color) {
        IGuiTexture tex;
        if (width <= 0 || height <= 0 || this.slides.length <= 0 || (tex = getCurrentFrame()) == null) {
            return;
        }
        tex.drawTexture(x, y, width, height, zDepth, partialTick, color);
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    @Deprecated
    public ResourceLocation getTexture() {
        IGuiTexture tex = getCurrentFrame();
        if (tex == null) {
            return null;
        }
        return tex.getTexture();
    }

    @Override // betterquesting.api2.client.gui.resources.textures.IGuiTexture
    @Deprecated
    public IGuiRect getBounds() {
        IGuiTexture tex = getCurrentFrame();
        if (tex == null) {
            return null;
        }
        return tex.getBounds();
    }

    @Nullable
    public IGuiTexture getCurrentFrame() {
        if (this.slides.length <= 0) {
            return null;
        }
        return this.slides[(int) Math.floor(((System.currentTimeMillis() / 1000.0d) % (this.slides.length * this.interval)) / this.interval)];
    }

    public IGuiTexture[] getAllFrames() {
        return this.slides;
    }
}
